"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Context = void 0;
const uuid_1 = require("uuid");
const types_1 = require("../../common/types");
const config_1 = require("../../common/config");
const error_1 = require("../../error");
const external_info_1 = require("./external-info");
const link_1 = require("./link");
const origin_1 = require("./origin");
const default_1 = require("../../common/default");
class Context extends default_1.Default {
    constructor(mode, msgType, id, creation) {
        error_1.ContextError.checkLength(id, config_1.MAX_ID_LENGTH);
        super();
        this.id = id || uuid_1.v4();
        this.mode = mode;
        this.msgType = msgType;
        this.creation = (creation || new Date()).toISOString();
    }
    addLinks(links) {
        if (!this.link)
            this.link = new Array();
        this.link.push(...links);
        return this;
    }
    setLevel(level) {
        this.level = level;
        return this;
    }
    setSecurityClassification(seClass) {
        this.seClass = seClass;
        return this;
    }
    setFreeText(freeText) {
        error_1.ContextError.checkLength(freeText, config_1.MAX_FREETEXT_LENGTH);
        this.freeText = freeText;
        return this;
    }
    setUrgency(urgency) {
        this.urgency = urgency;
        return this;
    }
    setOrigin(origin) {
        this.origin = origin;
        return this;
    }
    addExternalInfos(externals) {
        if (!this.externalInfo)
            this.externalInfo = new Array();
        this.externalInfo.push(...externals);
        return this;
    }
    static default() {
        return new Context(types_1.Mode.SYSTEM, types_1.MsgType.ERROR, config_1.NULL_UUID);
    }
    assign(source) {
        let key;
        const keys = Object.keys(source);
        if ((key = keys.find(f => f === 'id')))
            this.id = source[key];
        if ((key = keys.find(f => f === 'mode')))
            this.mode = source[key];
        if ((key = keys.find(f => f === 'msgType')))
            this.msgType = source[key];
        if ((key = keys.find(f => f === 'creation')))
            this.creation = source[key];
        if ((key = keys.find(f => f === 'link'))) {
            this.link = new Array();
            if (source[key] instanceof Array)
                source[key].forEach((add) => { var _a; return (_a = this.link) === null || _a === void 0 ? void 0 : _a.push(link_1.Link.default().assign(add)); });
            else
                this.link.push(link_1.Link.default().assign(source[key]));
        }
        if ((key = keys.find(f => f === 'level')))
            this.level = source[key];
        if ((key = keys.find(f => f === 'seClass')))
            this.seClass = source[key];
        if ((key = keys.find(f => f === 'freeText')))
            this.freeText = source[key];
        if ((key = keys.find(f => f === 'urgency')))
            this.urgency = source[key];
        if ((key = keys.find(f => f === 'origin')))
            this.origin = origin_1.Origin.default().assign(source[key]);
        if ((key = keys.find(f => f === 'externalInfo'))) {
            this.externalInfo = new Array();
            if (source[key] instanceof Array)
                source[key].forEach((add) => { var _a; return (_a = this.externalInfo) === null || _a === void 0 ? void 0 : _a.push(external_info_1.ExternalInfo.default().assign(add)); });
            else
                this.externalInfo.push(external_info_1.ExternalInfo.default().assign(source[key]));
        }
        return this;
    }
}
exports.Context = Context;
