import { Js2XmlFn, ParseOptions, Xml2JsFn } from '../common/parse';
import { EmsiStatus } from '../common/types';
import { Context } from "./context";
import { Event } from "./event";
import { Mission } from "./mission";
import { Resource } from "./resource";
/**
 * An EMSI describes a part of the operational picture at a particular time.
 * It is exchanged between nodes in order to transfer information and describes
 * events, resources and missions.  */
export declare class Emsi {
    /** Identifies the context of the EMSI. */
    context?: Context;
    /** Describes the event that the EMSI relates to. */
    event?: Event;
    /** Describes the missions which are completed, are ongoing, or are planned and is
     * related to the event and context reported in the EMSI. */
    mission?: Array<Mission>;
    /** Describes the resources (human, vehicles, other hardware, etc...) which the EMSI
     * node has the authority to deploy and is related to the event and context reported
     * in the EMSI. */
    resource?: Array<Resource>;
    /** Set the context of the EMSI (mandatory) */
    setContext(context: Context): this;
    /** Set the event of the EMSI (mandatory) */
    setEvent(event: Event): this;
    /** Add one or more missions */
    addMissions(missions: Mission[]): this;
    /** Add one or more resources */
    addResources(resources: Resource[]): this;
    /**
     * Returns a well-formed XML EMSI
     *
     * @remarks By default, tags are CamelCase formatted, and output is indented
     *
     * @param options Modifying certain behaviours for XML generation
     * @param fn An alternative function for generating XML
     * @returns The XML EMSI string
     */
    generateXml(options?: ParseOptions, fn?: Js2XmlFn): string;
    loadFromXml(xml: string, options?: ParseOptions, fn?: Xml2JsFn): this;
    /**
     * Check EMSI object
     * @beta
     */
    checkStatus(): EmsiStatus;
}
