"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EGeo = void 0;
const config_1 = require("../../common/config");
const default_1 = require("../../common/default");
const error_1 = require("../../error");
const location_1 = require("../location");
class EGeo extends default_1.Default {
    constructor(type, position) {
        error_1.EventError.checkLength(type, config_1.MAX_ETYPE_LENGTH);
        super();
        this.type = type;
        this.position = position;
    }
    setDatime(datime) {
        this.datime = datime;
        return this;
    }
    addWeather(weathers) {
        weathers.forEach(weather => error_1.EventError.checkLength(weather, config_1.MAX_WEATHER_LENGTH));
        if (!this.weather)
            this.weather = new Array();
        this.weather.push(...weathers);
        return this;
    }
    setFreeText(freeText) {
        error_1.EventError.checkLength(freeText, config_1.MAX_FREETEXT_LENGTH);
        this.freeText = freeText;
        return this;
    }
    setId(id) {
        error_1.EventError.checkLength(id, config_1.MAX_ID_LENGTH);
        this.id = id;
        return this;
    }
    setStatus(status) {
        this.status = status;
        return this;
    }
    static default() {
        return new EGeo('');
    }
    assign(source) {
        let key;
        const keys = Object.keys(source);
        if ((key = keys.find(f => f === 'datime')))
            this.datime = source[key];
        if ((key = keys.find(f => f === 'type')))
            this.type = source[key];
        if ((key = keys.find(f => f === 'weather'))) {
            this.weather = new Array();
            if (source[key] instanceof Array)
                source[key].forEach((add) => { var _a; return (_a = this.weather) === null || _a === void 0 ? void 0 : _a.push(add); });
            else
                this.weather.push(source[key]);
        }
        if ((key = keys.find(f => f === 'freeText')))
            this.freeText = source[key];
        if ((key = keys.find(f => f === 'position')))
            this.position = location_1.Position.default().assign(source[key]);
        if ((key = keys.find(f => f === 'id')))
            this.id = source[key];
        if ((key = keys.find(f => f === 'status')))
            this.status = source[key];
        return this;
    }
}
exports.EGeo = EGeo;
