"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Event = void 0;
const uuid_1 = require("uuid");
const config_1 = require("../../common/config");
const event_geo_1 = require("./event-geo");
const event_type_1 = require("./event-type");
const reference_1 = require("./reference");
const error_1 = require("../../error");
const casualties_1 = require("./casualties");
const default_1 = require("../../common/default");
class Event extends default_1.Default {
    constructor(id, name, mainEventId) {
        error_1.EventError.checkLength(id, config_1.MAX_ID_LENGTH);
        error_1.EventError.checkLength(name, config_1.MAX_NAME_LENGTH);
        error_1.EventError.checkLength(mainEventId, config_1.MAX_ID_LENGTH);
        super();
        this.id = id || uuid_1.v4();
        this.name = name;
        this.mainEventId = mainEventId;
    }
    setEventType(eType) {
        this.eType = eType;
        return this;
    }
    setSource(source) {
        this.source = source;
        return this;
    }
    setScale(scale) {
        this.scale = scale;
        return this;
    }
    setCertainly(certainly) {
        if (certainly < 0 || certainly > 100)
            throw new error_1.EventError(`Field "certainly" must be between 0 and 100 included`);
        this.certainly = certainly;
        return this;
    }
    setDeclDatime(decl) {
        this.declDatime = decl;
        return this;
    }
    setOccDatime(occ) {
        this.occDatime = occ;
        return this;
    }
    setObsDatime(obs) {
        this.obsDatime = obs;
        return this;
    }
    setStatus(status) {
        this.status = status;
        return this;
    }
    setRiskAssessmnt(risk) {
        this.riskAssessmnt = risk;
        return this;
    }
    addReferences(references) {
        if (!this.reference)
            this.reference = new Array();
        this.reference.push(...references);
        return this;
    }
    addCasualties(casualties) {
        if (!this.casualties)
            this.casualties = new Array();
        this.casualties.push(...casualties);
        return this;
    }
    addEventGeos(eGeo) {
        if (!this.eGeo)
            this.eGeo = new Array();
        this.eGeo.push(...eGeo);
        return this;
    }
    setCause(cause) {
        this.cause = cause;
        return this;
    }
    setFreeText(freeText) {
        error_1.EventError.checkLength(freeText, config_1.MAX_FREETEXT_LENGTH);
        this.freeText = freeText;
        return this;
    }
    static default() {
        return new Event(config_1.NULL_UUID);
    }
    assign(source) {
        let key;
        const keys = Object.keys(source);
        if ((key = keys.find(f => f === 'id')))
            this.id = source[key];
        if ((key = keys.find(f => f === 'name')))
            this.name = source[key];
        if ((key = keys.find(f => f === 'mainEventId')))
            this.mainEventId = source[key];
        if ((key = keys.find(f => f === 'eType')))
            this.eType = event_type_1.EType.default().assign(source[key]);
        if ((key = keys.find(f => f === 'source')))
            this.source = source[key];
        if ((key = keys.find(f => f === 'scale')))
            this.scale = source[key];
        if ((key = keys.find(f => f === 'certainly')))
            this.certainly = parseInt(source[key]);
        if ((key = keys.find(f => f === 'declDatime')))
            this.declDatime = source[key];
        if ((key = keys.find(f => f === 'occDatime')))
            this.occDatime = source[key];
        if ((key = keys.find(f => f === 'obsDatime')))
            this.obsDatime = source[key];
        if ((key = keys.find(f => f === 'status')))
            this.status = source[key];
        if ((key = keys.find(f => f === 'riskAssessmnt')))
            this.riskAssessmnt = source[key];
        if ((key = keys.find(f => f === 'reference'))) {
            this.reference = new Array();
            if (source[key] instanceof Array)
                source[key].forEach((add) => { var _a; return (_a = this.reference) === null || _a === void 0 ? void 0 : _a.push(reference_1.Reference.default().assign(add)); });
            else
                this.reference.push(reference_1.Reference.default().assign(source[key]));
        }
        if ((key = keys.find(f => f === 'eGeo'))) {
            this.eGeo = new Array();
            if (source[key] instanceof Array)
                source[key].forEach((add) => { var _a; return (_a = this.eGeo) === null || _a === void 0 ? void 0 : _a.push(event_geo_1.EGeo.default().assign(add)); });
            else
                this.eGeo.push(event_geo_1.EGeo.default().assign(source[key]));
        }
        if ((key = keys.find(f => f === 'casualties'))) {
            this.casualties = new Array();
            if (source[key] instanceof Array)
                source[key].forEach((add) => { var _a; return (_a = this.casualties) === null || _a === void 0 ? void 0 : _a.push(casualties_1.Casualties.default().assign(add)); });
            else
                this.casualties.push(casualties_1.Casualties.default().assign(source[key]));
        }
        if ((key = keys.find(f => f === 'cause')))
            this.cause = source[key];
        if ((key = keys.find(f => f === 'freeText')))
            this.freeText = source[key];
        return this;
    }
}
exports.Event = Event;
