"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Position = void 0;
const config_1 = require("../../common/config");
const default_1 = require("../../common/default");
const error_1 = require("../../error");
const coord_1 = require("./coord");
class Position extends default_1.Default {
    constructor(locId, name, type) {
        if (!locId && !name && !type)
            throw new error_1.PositionError(`All first level elements of 'Position' are optional, but at least one should be provided.`);
        super();
        this.locId = locId;
        this.name = name;
        this.type = type;
        this.coordSys = config_1.COORDSYS;
    }
    setHeightRole(heightRole) {
        this.heightRole = heightRole;
        return this;
    }
    addCoords(coords) {
        if (!this.coord)
            this.coord = new Array();
        this.coord.push(...coords);
        return this;
    }
    addAddresses(addresses) {
        addresses.forEach(add => error_1.PositionError.checkLength(add, config_1.MAX_ADDRESS_LENGTH));
        if (!this.address)
            this.address = new Array();
        this.address.push(...addresses);
        return this;
    }
    static default() {
        return new Position(config_1.NULL_UUID);
    }
    assign(source) {
        let key;
        const keys = Object.keys(source);
        if ((key = keys.find(f => f === 'locId')))
            this.locId = source[key];
        if ((key = keys.find(f => f === 'name')))
            this.name = source[key];
        if ((key = keys.find(f => f === 'type')))
            this.type = source[key];
        if ((key = keys.find(f => f === 'coordSys')))
            this.coordSys = source[key];
        if ((key = keys.find(f => f === 'heightRole')))
            this.heightRole = source[key];
        if ((key = keys.find(f => f === 'coord'))) {
            this.coord = new Array();
            if (source[key] instanceof Array)
                source[key].forEach((add) => { var _a; return (_a = this.coord) === null || _a === void 0 ? void 0 : _a.push(coord_1.Coord.default().assign(add)); });
            else
                this.coord.push(coord_1.Coord.default().assign(source[key]));
        }
        if ((key = keys.find(f => f === 'address'))) {
            this.address = new Array();
            if (source[key] instanceof Array)
                source[key].forEach((add) => { var _a; return (_a = this.address) === null || _a === void 0 ? void 0 : _a.push(add); });
            else
                this.address.push(source[key]);
        }
        return this;
    }
}
exports.Position = Position;
